"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.contract = exports.definition = exports.ToolConfigSchema = exports.unifiedMessageSchema = exports.learningSchema = exports.integrationSchema = exports.onStatusChangeSchema = exports.VersionedTextsSchema = exports.interruptSchema = exports.notificationSchema = void 0;
const core_1 = require("@ts-rest/core");
const zod_1 = require("zod");
const c = (0, core_1.initContract)();
const machineHeaders = {
    "x-machine-id": zod_1.z.string().optional(),
    "x-machine-sdk-version": zod_1.z.string().optional(),
    "x-machine-sdk-language": zod_1.z.string().optional(),
    "x-forwarded-for": zod_1.z.string().optional().optional(),
};
const functionReference = zod_1.z.object({
    service: zod_1.z.string(),
    function: zod_1.z.string(),
});
const anyObject = zod_1.z.object({}).passthrough();
exports.notificationSchema = zod_1.z.object({
    destination: zod_1.z
        .discriminatedUnion("type", [
        zod_1.z.object({
            type: zod_1.z.literal("slack"),
            channelId: zod_1.z.string().optional(),
            threadId: zod_1.z.string().optional(),
            userId: zod_1.z.string().optional(),
            email: zod_1.z.string().optional(),
        }),
        zod_1.z.object({
            type: zod_1.z.literal("email"),
            email: zod_1.z.string(),
        }),
    ])
        .optional(),
    message: zod_1.z.string().optional(),
});
exports.interruptSchema = zod_1.z.discriminatedUnion("type", [
    zod_1.z.object({
        type: zod_1.z.enum(["approval", "general"]),
        notification: exports.notificationSchema.optional(),
    }),
]);
exports.VersionedTextsSchema = zod_1.z.object({
    current: zod_1.z.object({
        version: zod_1.z.string(),
        content: zod_1.z.string(),
    }),
    history: zod_1.z.array(zod_1.z.object({
        version: zod_1.z.string(),
        content: zod_1.z.string(),
    })),
});
exports.onStatusChangeSchema = zod_1.z.preprocess(function temporaryPreprocessForBackwardsCompatibility(val) {
    if (val && typeof val === "object" && "type" in val) {
        return val;
    }
    if (val && typeof val === "object" && "function" in val) {
        return {
            type: "function",
            statuses: "statuses" in val ? val.statuses : ["done", "failed"],
            function: val.function,
        };
    }
    if (val && typeof val === "object" && "webhook" in val) {
        return {
            type: "webhook",
            statuses: "statuses" in val ? val.statuses : ["done", "failed"],
            webhook: val.webhook,
        };
    }
    return val;
}, zod_1.z.union([
    zod_1.z.object({
        type: zod_1.z.literal("function"),
        statuses: zod_1.z.array(zod_1.z.enum(["pending", "running", "paused", "done", "failed"])),
        function: functionReference.describe("A function to call when the run status changes"),
    }),
    zod_1.z.object({
        type: zod_1.z.literal("tool"),
        statuses: zod_1.z.array(zod_1.z.enum(["pending", "running", "paused", "done", "failed"])),
        tool: zod_1.z.string().describe("A tool to call when the run status changes"),
    }),
    zod_1.z.object({
        type: zod_1.z.literal("webhook"),
        statuses: zod_1.z.array(zod_1.z.enum(["pending", "running", "paused", "done", "failed"])),
        webhook: zod_1.z
            .string()
            .regex(/^https?:\/\/.+$/)
            .describe("A webhook URL to call when the run status changes"),
    }),
    zod_1.z.object({
        type: zod_1.z.literal("workflow"),
        statuses: zod_1.z.array(zod_1.z.enum(["pending", "running", "paused", "done", "failed"])),
        workflow: zod_1.z
            .object({
            executionId: zod_1.z.string().describe("The execution ID of the workflow"),
        })
            .describe("A workflow to run when the run status changes"),
    }),
]));
exports.integrationSchema = zod_1.z.object({
    toolhouse: zod_1.z
        .object({
        apiKey: zod_1.z.string(),
    })
        .optional()
        .nullable(),
    langfuse: zod_1.z
        .object({
        publicKey: zod_1.z.string(),
        secretKey: zod_1.z.string(),
        baseUrl: zod_1.z.string(),
        sendMessagePayloads: zod_1.z.boolean(),
    })
        .optional()
        .nullable(),
    tavily: zod_1.z
        .object({
        apiKey: zod_1.z.string(),
    })
        .optional()
        .nullable(),
    valtown: zod_1.z
        .object({
        endpoint: zod_1.z.string().url(),
        token: zod_1.z.string(),
    })
        .optional()
        .nullable(),
    slack: zod_1.z
        .object({
        nangoConnectionId: zod_1.z.string(),
        botUserId: zod_1.z.string(),
        teamId: zod_1.z.string(),
    })
        .optional()
        .nullable(),
    email: zod_1.z
        .object({
        connectionId: zod_1.z.string(),
        validateSPFandDKIM: zod_1.z.boolean().optional(),
    })
        .optional()
        .nullable(),
});
const genericMessageDataSchema = zod_1.z
    .object({
    message: zod_1.z.string(),
    details: zod_1.z.object({}).passthrough().optional(),
})
    .strict();
const resultDataSchema = zod_1.z
    .object({
    id: zod_1.z.string(),
    toolName: zod_1.z.string(),
    resultType: zod_1.z.enum(["resolution", "rejection"]),
    result: zod_1.z.object({}).passthrough(),
})
    .strict();
exports.learningSchema = zod_1.z.object({
    summary: zod_1.z
        .string()
        .describe("The new information that was learned. Be generic, do not refer to the entities."),
    entities: zod_1.z
        .array(zod_1.z.object({
        name: zod_1.z
            .string()
            .describe("The name of the entity this learning relates to."),
        type: zod_1.z.enum(["tool"]),
    }))
        .describe("The entities this learning relates to."),
    relevance: zod_1.z.object({
        temporality: zod_1.z
            .enum(["transient", "persistent"])
            .describe("How long do you expect this learning to be relevant for."),
    }),
});
const agentDataSchema = zod_1.z
    .object({
    done: zod_1.z.boolean().optional(),
    result: anyObject.optional(),
    message: zod_1.z.string().optional(),
    learnings: zod_1.z.array(exports.learningSchema).optional(),
    issue: zod_1.z.string().optional(),
    invocations: zod_1.z
        .array(zod_1.z.object({
        id: zod_1.z.string().optional(),
        toolName: zod_1.z.string(),
        reasoning: zod_1.z.string().optional(),
        input: zod_1.z.object({}).passthrough(),
    }))
        .optional(),
})
    .strict();
const peripheralMessageSchema = zod_1.z.object({
    id: zod_1.z.string(),
    createdAt: zod_1.z.date().optional(),
    pending: zod_1.z.boolean().optional(),
    metadata: zod_1.z.record(zod_1.z.unknown()).optional().nullable(),
});
exports.unifiedMessageSchema = zod_1.z.discriminatedUnion("type", [
    zod_1.z
        .object({
        type: zod_1.z.literal("agent"),
        data: agentDataSchema,
    })
        .merge(peripheralMessageSchema),
    zod_1.z
        .object({
        type: zod_1.z.literal("invocation-result"),
        data: resultDataSchema,
    })
        .merge(peripheralMessageSchema),
    zod_1.z
        .object({
        type: zod_1.z.literal("human"),
        data: genericMessageDataSchema,
    })
        .merge(peripheralMessageSchema),
    zod_1.z
        .object({
        type: zod_1.z.literal("template"),
        data: genericMessageDataSchema,
    })
        .merge(peripheralMessageSchema),
    zod_1.z
        .object({
        type: zod_1.z.literal("supervisor"),
        data: genericMessageDataSchema,
    })
        .merge(peripheralMessageSchema),
    zod_1.z
        .object({
        type: zod_1.z.literal("agent-invalid"),
        data: genericMessageDataSchema,
    })
        .merge(peripheralMessageSchema),
]);
exports.ToolConfigSchema = zod_1.z.object({
    cache: zod_1.z
        .object({
        keyPath: zod_1.z.string(),
        ttlSeconds: zod_1.z.number(),
    })
        .optional(),
    retryCountOnStall: zod_1.z.number().optional(),
    timeoutSeconds: zod_1.z.number().optional(),
    private: zod_1.z.boolean().default(false).optional(),
});
const RunSchema = zod_1.z.object({
    id: zod_1.z
        .string()
        .optional()
        .describe("The run ID. If not provided, a new run will be created. If provided, the run will be created with the given. If the run already exists, it will be returned.")
        .refine((val) => !val || /^[0-9A-Za-z-_.]{4,128}$/.test(val), "Run ID must contain only alphanumeric characters, dashes, underscores, and periods. Must be between 4 and 128 characters long."),
    runId: zod_1.z
        .string()
        .optional()
        .describe("Deprecated. Use `id` instead.")
        .refine((val) => !val || /^[0-9A-Za-z-_.]{4,128}$/.test(val), "Run ID must contain only alphanumeric characters, dashes, underscores, and periods. Must be between 4 and 128 characters long."),
    initialPrompt: zod_1.z
        .string()
        .optional()
        .describe("An initial 'human' message to trigger the run"),
    systemPrompt: zod_1.z.string().optional().describe("A system prompt for the run."),
    name: zod_1.z
        .string()
        .optional()
        .describe("The name of the run, if not provided it will be generated"),
    resultSchema: anyObject
        .optional()
        .describe("A JSON schema definition which the result object should conform to. By default the result will be a JSON object which does not conform to any schema"),
    tools: zod_1.z
        .array(zod_1.z.string())
        .optional()
        .describe("An array of tool names to make available to the run"),
    attachedFunctions: zod_1.z
        .array(functionReference)
        .optional()
        .describe("DEPRECATED, use tools instead"),
    onStatusChange: exports.onStatusChangeSchema
        .optional()
        .describe("Mechanism for receiving notifications when the run status changes"),
    tags: zod_1.z
        .record(zod_1.z.string())
        .optional()
        .describe("Run tags which can be used to filter runs"),
    input: zod_1.z
        .object({})
        .passthrough()
        .describe("Structured input arguments to merge with the initial prompt.")
        .optional(),
    context: anyObject
        .optional()
        .describe("Additional context to propogate to all Jobs in the Run"),
    reasoningTraces: zod_1.z
        .boolean()
        .default(true)
        .optional()
        .describe("Enable reasoning traces"),
    interactive: zod_1.z
        .boolean()
        .default(true)
        .describe("Allow the run to be continued with follow-up messages / message edits"),
    enableResultGrounding: zod_1.z
        .boolean()
        .default(false)
        .describe("Enable result grounding"),
});
exports.definition = {
    // Misc Endpoints
    live: {
        method: "GET",
        path: "/live",
        responses: {
            200: zod_1.z.object({
                status: zod_1.z.string(),
            }),
        },
    },
    createEphemeralSetup: {
        method: "POST",
        path: "/ephemeral-setup",
        responses: {
            200: zod_1.z.object({
                clusterId: zod_1.z.string(),
                apiKey: zod_1.z.string(),
            }),
        },
        body: zod_1.z.undefined(),
    },
    getContract: {
        method: "GET",
        path: "/contract",
        responses: {
            200: zod_1.z.object({
                contract: zod_1.z.string(),
            }),
        },
    },
    // Job Endpoints
    getJob: {
        method: "GET",
        path: "/clusters/:clusterId/jobs/:jobId",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            jobId: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.object({
                id: zod_1.z.string(),
                status: zod_1.z.string(),
                targetFn: zod_1.z.string(),
                executingMachineId: zod_1.z.string().nullable(),
                targetArgs: zod_1.z.string(),
                result: zod_1.z.string().nullable(),
                resultType: zod_1.z.string().nullable(),
                createdAt: zod_1.z.date(),
                approved: zod_1.z.boolean().nullable(),
                approvalRequested: zod_1.z.boolean().nullable(),
            }),
        },
    },
    createJob: {
        method: "POST",
        path: "/clusters/:clusterId/jobs",
        query: zod_1.z.object({
            waitTime: zod_1.z.coerce
                .number()
                .min(0)
                .max(20)
                .default(0)
                .describe("Time in seconds to keep the request open waiting for a response"),
        }),
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            function: zod_1.z.string().optional(),
            tool: zod_1.z.string().optional(),
            input: zod_1.z.object({}).passthrough(),
        }),
        responses: {
            401: zod_1.z.undefined(),
            200: zod_1.z.object({
                id: zod_1.z.string(),
                result: zod_1.z.any().nullable(),
                resultType: zod_1.z.enum(["resolution", "rejection", "interrupt"]).nullable(),
                status: zod_1.z.enum([
                    "pending",
                    "running",
                    "success",
                    "failure",
                    "stalled",
                    "interrupted",
                ]),
            }),
        },
    },
    cancelJob: {
        method: "POST",
        path: "/clusters/:clusterId/jobs/:jobId/cancel",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            jobId: zod_1.z.string(),
        }),
        responses: {
            204: zod_1.z.undefined(),
            401: zod_1.z.undefined(),
        },
        body: zod_1.z.undefined(),
    },
    createJobResult: {
        method: "POST",
        path: "/clusters/:clusterId/jobs/:jobId/result",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
            ...machineHeaders,
        }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            jobId: zod_1.z.string(),
        }),
        responses: {
            204: zod_1.z.undefined(),
            401: zod_1.z.undefined(),
        },
        body: zod_1.z.object({
            result: zod_1.z.any(),
            resultType: zod_1.z.enum(["resolution", "rejection", "interrupt"]),
            meta: zod_1.z.object({
                functionExecutionTime: zod_1.z.number().optional(),
            }),
        }),
    },
    listJobs: {
        method: "GET",
        path: "/clusters/:clusterId/jobs",
        query: zod_1.z.object({
            tools: zod_1.z
                .string()
                .optional()
                .describe("Comma-separated list of tools to poll"),
            status: zod_1.z
                .enum(["pending", "running", "paused", "done", "failed"])
                .default("pending"),
            limit: zod_1.z.coerce.number().min(1).max(20).default(10),
            acknowledge: zod_1.z.coerce
                .boolean()
                .default(false)
                .describe("Should retrieved Jobs be marked as running"),
            waitTime: zod_1.z.coerce
                .number()
                .min(0)
                .max(20)
                .default(0)
                .describe("Time in seconds to keep the request open waiting for a response"),
        }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
            ...machineHeaders,
        }),
        responses: {
            401: zod_1.z.undefined(),
            410: zod_1.z.object({
                message: zod_1.z.string(),
            }),
            200: zod_1.z.array(zod_1.z.object({
                id: zod_1.z.string(),
                function: zod_1.z.string(),
                input: zod_1.z.any(),
                authContext: zod_1.z.any().nullable(),
                runContext: zod_1.z.any().nullable(),
                approved: zod_1.z.boolean(),
            })),
        },
    },
    createJobApproval: {
        method: "POST",
        path: "/clusters/:clusterId/jobs/:jobId/approval",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            jobId: zod_1.z.string(),
        }),
        responses: {
            204: zod_1.z.undefined(),
            404: zod_1.z.object({
                message: zod_1.z.string(),
            }),
        },
        body: zod_1.z.object({
            approved: zod_1.z.boolean(),
        }),
    },
    createMachine: {
        method: "POST",
        path: "/machines",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
            ...machineHeaders,
        }),
        body: zod_1.z.object({
            functions: zod_1.z
                .array(zod_1.z.object({
                name: zod_1.z.string(),
                description: zod_1.z.string().optional(),
                schema: zod_1.z.string().optional(),
                config: exports.ToolConfigSchema.optional(),
            }))
                .optional(),
            tools: zod_1.z
                .array(zod_1.z.object({
                name: zod_1.z.string(),
                description: zod_1.z.string().optional(),
                schema: zod_1.z.string().optional(),
                config: exports.ToolConfigSchema.optional(),
            }))
                .optional(),
        }),
        responses: {
            200: zod_1.z.object({
                clusterId: zod_1.z.string(),
            }),
            204: zod_1.z.undefined(),
        },
    },
    // Cluster Endpoints
    createCluster: {
        method: "POST",
        path: "/clusters",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            204: zod_1.z.undefined(),
        },
        body: zod_1.z.object({
            description: zod_1.z
                .string()
                .describe("Human readable description of the cluster"),
            name: zod_1.z
                .string()
                .optional()
                .describe("Human readable name of the cluster"),
            isDemo: zod_1.z
                .boolean()
                .optional()
                .default(false)
                .describe("Whether the cluster is a demo cluster"),
        }),
    },
    deleteCluster: {
        method: "DELETE",
        path: "/clusters/:clusterId",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        body: zod_1.z.undefined(),
        responses: {
            204: zod_1.z.undefined(),
        },
    },
    updateCluster: {
        method: "PUT",
        path: "/clusters/:clusterId",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            204: zod_1.z.undefined(),
            401: zod_1.z.undefined(),
        },
        body: zod_1.z.object({
            name: zod_1.z.string().optional(),
            description: zod_1.z.string().optional(),
            debug: zod_1.z
                .boolean()
                .optional()
                .describe("Enable additional logging (Including prompts and results) for use by Inferable support"),
            enableCustomAuth: zod_1.z.boolean().optional(),
            enableKnowledgebase: zod_1.z.boolean().optional(),
            handleCustomAuthFunction: zod_1.z.string().optional(),
        }),
    },
    getCluster: {
        method: "GET",
        path: "/clusters/:clusterId",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.object({
                id: zod_1.z.string(),
                name: zod_1.z.string(),
                description: zod_1.z.string().nullable(),
                createdAt: zod_1.z.number(),
                debug: zod_1.z.boolean(),
                enableCustomAuth: zod_1.z.boolean(),
                handleCustomAuthFunction: zod_1.z.string().nullable(),
                isDemo: zod_1.z.boolean(),
                machines: zod_1.z.array(zod_1.z.object({
                    id: zod_1.z.string(),
                    lastPingAt: zod_1.z.number().nullable(),
                    ip: zod_1.z.string().nullable(),
                    sdkVersion: zod_1.z.string().nullable(),
                    sdkLanguage: zod_1.z.string().nullable(),
                })),
                tools: zod_1.z.array(zod_1.z.object({
                    name: zod_1.z.string(),
                    description: zod_1.z.string().nullable(),
                    schema: zod_1.z.unknown().nullable(),
                    config: zod_1.z.unknown().nullable(),
                    shouldExpire: zod_1.z.boolean(),
                    createdAt: zod_1.z.number(),
                    lastPingAt: zod_1.z.number().nullable(),
                })),
            }),
            401: zod_1.z.undefined(),
            404: zod_1.z.undefined(),
        },
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
    },
    listClusters: {
        method: "GET",
        path: "/clusters",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                id: zod_1.z.string(),
                name: zod_1.z.string(),
                createdAt: zod_1.z.date(),
                description: zod_1.z.string().nullable(),
            })),
            401: zod_1.z.undefined(),
        },
    },
    // Integration Endpoints
    getIntegrations: {
        method: "GET",
        path: "/clusters/:clusterId/integrations",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: exports.integrationSchema,
        },
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
    },
    upsertIntegrations: {
        method: "PUT",
        path: "/clusters/:clusterId/integrations",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.undefined(),
            401: zod_1.z.undefined(),
            400: zod_1.z.object({
                message: zod_1.z.string(),
            }),
        },
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        body: exports.integrationSchema,
    },
    // Event Endpoints
    listEvents: {
        method: "GET",
        path: "/clusters/:clusterId/events",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                type: zod_1.z.string(),
                machineId: zod_1.z.string().nullable(),
                createdAt: zod_1.z.date(),
                jobId: zod_1.z.string().nullable(),
                targetFn: zod_1.z.string().nullable(),
                resultType: zod_1.z.string().nullable(),
                status: zod_1.z.string().nullable(),
                runId: zod_1.z.string().nullable(),
                meta: zod_1.z.any().nullable(),
                id: zod_1.z.string(),
            })),
            401: zod_1.z.undefined(),
            404: zod_1.z.undefined(),
        },
        query: zod_1.z.object({
            type: zod_1.z.string().optional(),
            jobId: zod_1.z.string().optional(),
            machineId: zod_1.z.string().optional(),
            runId: zod_1.z.string().optional(),
            includeMeta: zod_1.z.string().optional(),
        }),
    },
    getEventMeta: {
        method: "GET",
        path: "/clusters/:clusterId/events/:eventId/meta",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.object({
                type: zod_1.z.string(),
                machineId: zod_1.z.string().nullable(),
                createdAt: zod_1.z.date(),
                jobId: zod_1.z.string().nullable(),
                targetFn: zod_1.z.string().nullable(),
                resultType: zod_1.z.string().nullable(),
                status: zod_1.z.string().nullable(),
                meta: zod_1.z.unknown(),
                id: zod_1.z.string(),
            }),
            401: zod_1.z.undefined(),
            404: zod_1.z.undefined(),
        },
    },
    listUsageActivity: {
        method: "GET",
        path: "/clusters/:clusterId/usage",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.object({
                modelUsage: zod_1.z.array(zod_1.z.object({
                    date: zod_1.z.string(),
                    modelId: zod_1.z.string().nullable(),
                    totalInputTokens: zod_1.z.number(),
                    totalOutputTokens: zod_1.z.number(),
                    totalModelInvocations: zod_1.z.number(),
                })),
                runs: zod_1.z.array(zod_1.z.object({
                    date: zod_1.z.string(),
                    totalRuns: zod_1.z.number(),
                })),
            }),
        },
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
    },
    // Run Endpoints
    createRun: {
        method: "POST",
        path: "/clusters/:clusterId/runs",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
            "x-provider-key": zod_1.z.string().optional(),
            "x-provider-model": zod_1.z
                .enum([
                "claude-3-7-sonnet-20250219",
                "claude-3-7-sonnet-latest",
                "claude-3-5-sonnet-20241022",
                "claude-3-5-sonnet-latest",
                "claude-3-5-sonnet-20240620",
                "claude-3-5-haiku-20241022",
                "claude-3-5-haiku-latest",
            ])
                .optional(),
            "x-provider-url": zod_1.z
                .literal("https://api.anthropic.com")
                .default("https://api.anthropic.com"),
        }),
        body: RunSchema,
        responses: {
            201: zod_1.z.object({
                id: zod_1.z.string().describe("The id of the newly created run"),
                status: zod_1.z
                    .enum(["pending", "running", "paused", "done", "failed"])
                    .describe("The status of the run"),
                result: anyObject.nullable().describe("The result of the run"),
            }),
            401: zod_1.z.undefined(),
            400: zod_1.z.object({
                message: zod_1.z.string(),
            }),
        },
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
    },
    deleteRun: {
        method: "DELETE",
        path: "/clusters/:clusterId/runs/:runId",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        body: zod_1.z.undefined(),
        responses: {
            204: zod_1.z.undefined(),
            401: zod_1.z.undefined(),
        },
        pathParams: zod_1.z.object({
            runId: zod_1.z.string(),
            clusterId: zod_1.z.string(),
        }),
    },
    listRuns: {
        method: "GET",
        path: "/clusters/:clusterId/runs",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        query: zod_1.z.object({
            userId: zod_1.z.string().optional(),
            test: zod_1.z.coerce
                .string()
                .transform((value) => value === "true")
                .optional(),
            limit: zod_1.z.coerce.number().min(10).max(50).default(50),
            tags: zod_1.z
                .string()
                .optional()
                .describe("Filter runs by a tag value (value:key)"),
            type: zod_1.z.enum(["conversation", "workflow", "all"]).default("all"),
        }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                id: zod_1.z.string(),
                name: zod_1.z.string(),
                userId: zod_1.z.string().nullable(),
                createdAt: zod_1.z.date(),
                type: zod_1.z.enum(["single-step", "multi-step"]),
                status: zod_1.z
                    .enum(["pending", "running", "paused", "done", "failed"])
                    .nullable(),
                test: zod_1.z.boolean(),
                feedbackScore: zod_1.z.number().nullable(),
                workflowExecutionId: zod_1.z.string().nullable(),
                workflowVersion: zod_1.z.number().nullable(),
                workflowName: zod_1.z.string().nullable(),
            })),
            401: zod_1.z.undefined(),
        },
    },
    getRun: {
        method: "GET",
        path: "/clusters/:clusterId/runs/:runId",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.object({
                id: zod_1.z.string(),
                userId: zod_1.z.string().nullable(),
                type: zod_1.z.enum(["single-step", "multi-step"]).nullable(),
                status: zod_1.z
                    .enum(["pending", "running", "paused", "done", "failed"])
                    .nullable(),
                failureReason: zod_1.z.string().nullable(),
                test: zod_1.z.boolean(),
                feedbackComment: zod_1.z.string().nullable(),
                feedbackScore: zod_1.z.number().nullable(),
                context: zod_1.z.any().nullable(),
                authContext: zod_1.z.any().nullable(),
                result: anyObject.nullable(),
                tags: zod_1.z.record(zod_1.z.string()).nullable(),
                tools: zod_1.z.array(zod_1.z.string()).nullable(),
            }),
            401: zod_1.z.undefined(),
        },
    },
    createFeedback: {
        method: "POST",
        path: "/clusters/:clusterId/runs/:runId/feedback",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            comment: zod_1.z.string().describe("Feedback comment").nullable(),
            score: zod_1.z
                .number()
                .describe("Score between 0 and 1")
                .min(0)
                .max(1)
                .nullable(),
        }),
        responses: {
            204: zod_1.z.undefined(),
            401: zod_1.z.undefined(),
            404: zod_1.z.undefined(),
        },
        pathParams: zod_1.z.object({
            runId: zod_1.z.string(),
            clusterId: zod_1.z.string(),
        }),
    },
    oas: {
        method: "GET",
        path: "/public/oas.json",
        responses: {
            200: zod_1.z.unknown(),
        },
    },
    // Message Endpoints
    createMessage: {
        method: "POST",
        path: "/clusters/:clusterId/runs/:runId/messages",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            id: zod_1.z
                .string()
                .length(26)
                .regex(/^[0-9a-z]+$/i)
                .optional(),
            message: zod_1.z.string(),
            type: zod_1.z.enum(["human", "supervisor"]).optional(),
        }),
        responses: {
            201: zod_1.z.undefined(),
            401: zod_1.z.undefined(),
        },
        pathParams: zod_1.z.object({
            runId: zod_1.z.string(),
            clusterId: zod_1.z.string(),
        }),
    },
    listMessages: {
        method: "GET",
        path: "/clusters/:clusterId/runs/:runId/messages",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        query: zod_1.z.object({
            waitTime: zod_1.z.coerce
                .number()
                .min(0)
                .max(20)
                .default(0)
                .describe("Time in seconds to keep the request open waiting for a response"),
            after: zod_1.z.string().default("0"),
            limit: zod_1.z.coerce.number().min(10).max(50).default(50),
        }),
        responses: {
            200: zod_1.z.array(exports.unifiedMessageSchema),
            401: zod_1.z.undefined(),
        },
    },
    // API Key Endpoints
    createApiKey: {
        method: "POST",
        path: "/clusters/:clusterId/api-keys",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            name: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.object({
                id: zod_1.z.string(),
                key: zod_1.z.string(),
            }),
        },
    },
    listApiKeys: {
        method: "GET",
        path: "/clusters/:clusterId/api-keys",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                id: zod_1.z.string(),
                name: zod_1.z.string(),
                createdAt: zod_1.z.date(),
                createdBy: zod_1.z.string(),
                revokedAt: zod_1.z.date().nullable(),
            })),
        },
    },
    revokeApiKey: {
        method: "DELETE",
        path: "/clusters/:clusterId/api-keys/:keyId",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            keyId: zod_1.z.string(),
        }),
        body: zod_1.z.undefined(),
        responses: {
            204: zod_1.z.undefined(),
        },
    },
    listMachines: {
        method: "GET",
        path: "/clusters/:clusterId/machines",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        query: zod_1.z.object({
            limit: zod_1.z.coerce.number().min(10).max(50).default(50),
        }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                id: zod_1.z.string(),
                lastPingAt: zod_1.z.date(),
                ip: zod_1.z.string(),
            })),
        },
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
    },
    getRunTimeline: {
        method: "GET",
        path: "/clusters/:clusterId/runs/:runId/timeline",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        query: zod_1.z.object({
            messagesAfter: zod_1.z.string().default("0"),
            activityAfter: zod_1.z.string().default("0"),
        }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            runId: zod_1.z.string(),
        }),
        responses: {
            404: zod_1.z.undefined(),
            200: zod_1.z.object({
                messages: zod_1.z.array(exports.unifiedMessageSchema),
                activity: zod_1.z.array(zod_1.z.object({
                    id: zod_1.z.string(),
                    type: zod_1.z.string(),
                    machineId: zod_1.z.string().nullable(),
                    createdAt: zod_1.z.date(),
                    jobId: zod_1.z.string().nullable(),
                    targetFn: zod_1.z.string().nullable(),
                })),
                jobs: zod_1.z.array(zod_1.z.object({
                    id: zod_1.z.string(),
                    status: zod_1.z.string(),
                    targetFn: zod_1.z.string(),
                    resultType: zod_1.z.string().nullable(),
                    createdAt: zod_1.z.date(),
                    approved: zod_1.z.boolean().nullable(),
                    approvalRequested: zod_1.z.boolean().nullable(),
                })),
                run: zod_1.z.object({
                    id: zod_1.z.string(),
                    userId: zod_1.z.string().nullable(),
                    status: zod_1.z
                        .enum(["pending", "running", "paused", "done", "failed"])
                        .nullable(),
                    failureReason: zod_1.z.string().nullable(),
                    test: zod_1.z.boolean(),
                    context: zod_1.z.any().nullable(),
                    authContext: zod_1.z.any().nullable(),
                    feedbackComment: zod_1.z.string().nullable(),
                    feedbackScore: zod_1.z.number().nullable(),
                    result: anyObject.nullable().optional(),
                    tags: zod_1.z.record(zod_1.z.string()).nullable().optional(),
                    tools: zod_1.z.array(zod_1.z.string()).nullable(),
                    name: zod_1.z.string().nullable(),
                    systemPrompt: zod_1.z.string().nullable(),
                    interactive: zod_1.z.boolean(),
                    workflowExecutionId: zod_1.z.string().nullable(),
                    workflowVersion: zod_1.z.number().nullable(),
                    workflowName: zod_1.z.string().nullable(),
                }),
            }),
        },
    },
    // Nango Endpoints
    createNangoSession: {
        method: "POST",
        path: "/clusters/:clusterId/nango/sessions",
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        body: zod_1.z.object({
            integration: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.object({
                token: zod_1.z.string(),
            }),
        },
    },
    createNangoEvent: {
        method: "POST",
        path: "/nango/events",
        headers: zod_1.z.object({ "x-nango-signature": zod_1.z.string() }),
        body: zod_1.z.object({}).passthrough(),
        responses: {
            200: zod_1.z.undefined(),
        },
    },
    // List Workflows
    listWorkflows: {
        method: "GET",
        path: "/clusters/:clusterId/workflows",
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                name: zod_1.z.string(),
                version: zod_1.z.number(),
                description: zod_1.z.string().nullable(),
                schema: zod_1.z.string().nullable(),
            })),
            401: zod_1.z.undefined(),
        },
    },
    // Workflow Endpoints
    createWorkflowExecution: {
        method: "POST",
        path: "/clusters/:clusterId/workflows/:workflowName/executions",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            workflowName: zod_1.z.string(),
        }),
        body: zod_1.z
            .object({
            executionId: zod_1.z.string(),
        })
            .passthrough(),
        responses: {
            201: zod_1.z.object({ jobId: zod_1.z.string() }),
        },
    },
    createWorkflowLogLegacy: {
        method: "POST",
        path: "/clusters/:clusterId/workflow-executions/:executionId/logs",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            executionId: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            status: zod_1.z.enum(["info", "warn", "error"]),
            data: zod_1.z.object({}).passthrough(),
        }),
        responses: {
            201: zod_1.z.object({
                id: zod_1.z.string(),
                status: zod_1.z.enum(["info", "warn", "error"]),
                workflowExecutionId: zod_1.z.string(),
                createdAt: zod_1.z.date(),
            }),
        },
    },
    createWorkflowLog: {
        method: "POST",
        path: "/clusters/:clusterId/workflows/:workflowName/executions/:executionId/logs",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            workflowName: zod_1.z.string(),
            clusterId: zod_1.z.string(),
            executionId: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            status: zod_1.z.enum(["info", "warn", "error"]),
            data: zod_1.z.object({}).passthrough(),
        }),
        responses: {
            201: zod_1.z.undefined(),
        },
    },
    createWorkflowNotification: {
        method: "POST",
        path: "/clusters/:clusterId/workflows/:workflowName/executions/:executionId/notification",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            executionId: zod_1.z.string(),
        }),
        body: exports.notificationSchema,
        responses: {
            201: zod_1.z.undefined(),
        },
    },
    listWorkflowExecutions: {
        method: "GET",
        path: "/clusters/:clusterId/workflow-executions",
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        query: zod_1.z.object({
            workflowName: zod_1.z.string().optional(),
            workflowVersion: zod_1.z.string().optional(),
            workflowExecutionId: zod_1.z.string().optional(),
            workflowExecutionStatus: zod_1.z
                .enum([
                "pending",
                "running",
                "success",
                "failure",
                "stalled",
                "interrupted",
            ])
                .optional(),
            limit: zod_1.z.coerce.number().min(10).max(50).default(50),
        }),
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                execution: zod_1.z.object({
                    id: zod_1.z.string(),
                    workflowName: zod_1.z.string(),
                    workflowVersion: zod_1.z.number(),
                    jobId: zod_1.z.string(),
                    createdAt: zod_1.z.date(),
                    updatedAt: zod_1.z.date(),
                }),
                job: zod_1.z.object({
                    id: zod_1.z.string().nullable(),
                    status: zod_1.z
                        .enum([
                        "pending",
                        "running",
                        "success",
                        "failure",
                        "stalled",
                        "interrupted",
                    ])
                        .nullable(),
                    targetFn: zod_1.z.string().nullable(),
                    executingMachineId: zod_1.z.string().nullable().optional(),
                    targetArgs: zod_1.z.string().nullable(),
                    result: zod_1.z.string().nullable(),
                    resultType: zod_1.z.string().nullable(),
                    createdAt: zod_1.z.date(),
                    approvalRequested: zod_1.z.boolean().nullable().optional(),
                    approved: zod_1.z.boolean().nullable().optional(),
                }),
                runs: zod_1.z.array(zod_1.z.object({
                    id: zod_1.z.string().nullable(),
                    name: zod_1.z.string().nullable(),
                    createdAt: zod_1.z.date().nullable(),
                    status: zod_1.z
                        .enum(["pending", "running", "paused", "done", "failed"])
                        .nullable(),
                    failureReason: zod_1.z.string().nullable(),
                    type: zod_1.z.enum(["single-step", "multi-step"]).nullable(),
                })),
            })),
            401: zod_1.z.undefined(),
        },
    },
    getWorkflowExecutionTimeline: {
        method: "GET",
        path: "/clusters/:clusterId/workflows/:workflowName/executions/:executionId/timeline",
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            workflowName: zod_1.z.string(),
            executionId: zod_1.z.string(),
        }),
        responses: {
            404: zod_1.z.undefined(),
            200: zod_1.z.object({
                events: zod_1.z.array(zod_1.z.object({
                    type: zod_1.z.string(),
                    machineId: zod_1.z.string().nullable(),
                    createdAt: zod_1.z.date(),
                    jobId: zod_1.z.string().nullable(),
                    targetFn: zod_1.z.string().nullable(),
                    resultType: zod_1.z.string().nullable(),
                    status: zod_1.z.string().nullable(),
                    runId: zod_1.z.string().nullable(),
                    meta: zod_1.z.any().nullable(),
                    id: zod_1.z.string(),
                })),
                runs: zod_1.z.array(zod_1.z.object({
                    id: zod_1.z.string(),
                    name: zod_1.z.string(),
                    userId: zod_1.z.string().nullable(),
                    failureReason: zod_1.z.string().nullable(),
                    createdAt: zod_1.z.date(),
                    type: zod_1.z.enum(["single-step", "multi-step"]),
                    status: zod_1.z
                        .enum(["pending", "running", "paused", "done", "failed"])
                        .nullable(),
                })),
                execution: zod_1.z.object({
                    id: zod_1.z.string(),
                    workflowName: zod_1.z.string(),
                    workflowVersion: zod_1.z.number(),
                    createdAt: zod_1.z.date(),
                    job: zod_1.z.object({
                        id: zod_1.z.string(),
                        status: zod_1.z.string(),
                        targetFn: zod_1.z.string(),
                        executingMachineId: zod_1.z.string().nullable(),
                        targetArgs: zod_1.z.string(),
                        result: zod_1.z.string().nullable(),
                        resultType: zod_1.z.string().nullable(),
                        createdAt: zod_1.z.date(),
                        approved: zod_1.z.boolean().nullable(),
                        approvalRequested: zod_1.z.boolean().nullable(),
                    }),
                }),
                memos: zod_1.z.array(zod_1.z.object({
                    key: zod_1.z.string(),
                    value: zod_1.z.string(),
                    createdAt: zod_1.z.date(),
                })),
                structured: zod_1.z.array(zod_1.z.object({
                    key: zod_1.z.string(),
                    value: zod_1.z.string(),
                    createdAt: zod_1.z.date(),
                })),
            }),
        },
    },
    // KV Endpoints
    setClusterKV: {
        method: "PUT",
        path: "/clusters/:clusterId/keys/:key",
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            key: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            onConflict: zod_1.z.enum(["replace", "doNothing"]),
            value: zod_1.z.string(),
        }),
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        responses: {
            200: zod_1.z.object({
                value: zod_1.z.string(),
            }),
        },
    },
    getClusterKV: {
        method: "GET",
        path: "/clusters/:clusterId/keys/:key/value",
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
            key: zod_1.z.string(),
        }),
        headers: zod_1.z.object({ authorization: zod_1.z.string() }),
        responses: {
            200: zod_1.z.object({
                value: zod_1.z.string(),
            }),
        },
    },
    // Tool Endpoints
    listTools: {
        method: "GET",
        path: "/clusters/:clusterId/tools",
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
        }),
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        responses: {
            200: zod_1.z.array(zod_1.z.object({
                name: zod_1.z.string(),
                description: zod_1.z.string().nullable(),
                schema: zod_1.z.string().nullable(),
                config: exports.ToolConfigSchema.nullable(),
                shouldExpire: zod_1.z.boolean(),
                lastPingAt: zod_1.z.date().nullable(),
                createdAt: zod_1.z.date(),
            })),
            401: zod_1.z.undefined(),
        },
    },
    // L1M Endpoints
    // https://github.com/inferablehq/l1m
    l1mStructured: {
        method: "POST",
        path: "/clusters/:clusterId/l1m/structured",
        pathParams: zod_1.z.object({
            clusterId: zod_1.z.string(),
        }),
        body: zod_1.z.object({
            input: zod_1.z.string(),
            instructions: zod_1.z.string().optional(),
            schema: zod_1.z.record(zod_1.z.any()),
        }),
        headers: zod_1.z.object({
            authorization: zod_1.z.string(),
            "x-provider-model": zod_1.z.string().optional(),
            "x-provider-url": zod_1.z.string().optional(),
            "x-provider-key": zod_1.z.string().optional(),
            "x-max-attempts": zod_1.z.string().optional().default("3"),
            "x-cache-ttl": zod_1.z.string().optional(),
            "x-workflow-execution-id": zod_1.z.string().optional(),
        }),
        responses: {
            200: zod_1.z.object({
                data: zod_1.z.record(zod_1.z.any()),
            }),
        },
    },
};
exports.contract = c.router(exports.definition);
//# sourceMappingURL=contract.js.map