/**
 * Provides raw API access to the Inferable API.
 */
export declare const createApiClient: ({ baseUrl, machineId, clientAbortController, apiSecret, }: {
    baseUrl?: string;
    machineId?: string;
    clientAbortController?: AbortController;
    apiSecret?: string;
}) => {
    readonly live: (args?: {
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: Record<string, string | undefined> | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
    } | undefined) => Promise<{
        status: 200;
        body: {
            status: string;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createEphemeralSetup: (args?: {
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: Record<string, string | undefined> | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
    } | undefined) => Promise<{
        status: 200;
        body: {
            apiKey: string;
            clusterId: string;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getContract: (args?: {
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: Record<string, string | undefined> | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
    } | undefined) => Promise<{
        status: 200;
        body: {
            contract: string;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getJob: (args: {
        params: {
            clusterId: string;
            jobId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            status: string;
            id: string;
            resultType: string | null;
            result: string | null;
            createdAt: Date;
            targetFn: string;
            executingMachineId: string | null;
            targetArgs: string;
            approved: boolean | null;
            approvalRequested: boolean | null;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createJob: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            input: {} & {
                [k: string]: unknown;
            };
            function?: string | undefined;
            tool?: string | undefined;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        query?: {
            waitTime?: number | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            status: "pending" | "running" | "success" | "failure" | "stalled" | "interrupted";
            id: string;
            resultType: "resolution" | "rejection" | "interrupt" | null;
            result?: any;
        };
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly cancelJob: (args: {
        params: {
            clusterId: string;
            jobId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createJobResult: (args: {
        params: {
            clusterId: string;
            jobId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            resultType: "resolution" | "rejection" | "interrupt";
            meta: {
                functionExecutionTime?: number | undefined;
            };
            result?: any;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
            "x-machine-id"?: undefined;
            "x-machine-sdk-version"?: undefined;
            "x-machine-sdk-language"?: undefined;
            "x-forwarded-for"?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            "x-forwarded-for"?: string | undefined;
            authorization?: string | undefined;
            "x-machine-id"?: string | undefined;
            "x-machine-sdk-version"?: string | undefined;
            "x-machine-sdk-language"?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listJobs: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
            "x-machine-id"?: undefined;
            "x-machine-sdk-version"?: undefined;
            "x-machine-sdk-language"?: undefined;
            "x-forwarded-for"?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            "x-forwarded-for"?: string | undefined;
            authorization?: string | undefined;
            "x-machine-id"?: string | undefined;
            "x-machine-sdk-version"?: string | undefined;
            "x-machine-sdk-language"?: string | undefined;
        } | undefined;
        query?: {
            status?: "pending" | "running" | "paused" | "done" | "failed" | undefined;
            tools?: string | undefined;
            waitTime?: number | undefined;
            limit?: number | undefined;
            acknowledge?: boolean | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            function: string;
            id: string;
            approved: boolean;
            input?: any;
            authContext?: any;
            runContext?: any;
        }[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 410;
        body: {
            message: string;
        };
        headers: Headers;
    } | {
        status: 204 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createJobApproval: (args: {
        params: {
            clusterId: string;
            jobId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            approved: boolean;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 404;
        body: {
            message: string;
        };
        headers: Headers;
    } | {
        status: 200 | 401 | 410 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createMachine: (args?: {
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
            "x-machine-id"?: undefined;
            "x-machine-sdk-version"?: undefined;
            "x-machine-sdk-language"?: undefined;
            "x-forwarded-for"?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            "x-forwarded-for"?: string | undefined;
            authorization?: string | undefined;
            "x-machine-id"?: string | undefined;
            "x-machine-sdk-version"?: string | undefined;
            "x-machine-sdk-language"?: string | undefined;
        } | undefined;
        body?: {
            tools?: {
                name: string;
                description?: string | undefined;
                schema?: string | undefined;
                config?: {
                    cache?: {
                        keyPath: string;
                        ttlSeconds: number;
                    } | undefined;
                    retryCountOnStall?: number | undefined;
                    timeoutSeconds?: number | undefined;
                    private?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            functions?: {
                name: string;
                description?: string | undefined;
                schema?: string | undefined;
                config?: {
                    cache?: {
                        keyPath: string;
                        ttlSeconds: number;
                    } | undefined;
                    retryCountOnStall?: number | undefined;
                    timeoutSeconds?: number | undefined;
                    private?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
    } | undefined) => Promise<{
        status: 200;
        body: {
            clusterId: string;
        };
        headers: Headers;
    } | {
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 401 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createCluster: (args: {
        cache?: RequestCache | undefined;
        body: {
            description: string;
            name?: string | undefined;
            isDemo?: boolean | undefined;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 401 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly deleteCluster: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 401 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly updateCluster: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        body?: {
            name?: string | undefined;
            description?: string | undefined;
            debug?: boolean | undefined;
            enableCustomAuth?: boolean | undefined;
            enableKnowledgebase?: boolean | undefined;
            handleCustomAuthFunction?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getCluster: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            id: string;
            name: string;
            createdAt: number;
            tools: {
                name: string;
                createdAt: number;
                description: string | null;
                lastPingAt: number | null;
                shouldExpire: boolean;
                schema?: unknown;
                config?: unknown;
            }[];
            description: string | null;
            isDemo: boolean;
            debug: boolean;
            enableCustomAuth: boolean;
            handleCustomAuthFunction: string | null;
            machines: {
                id: string;
                lastPingAt: number | null;
                ip: string | null;
                sdkVersion: string | null;
                sdkLanguage: string | null;
            }[];
        };
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 404;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listClusters: (args?: {
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    } | undefined) => Promise<{
        status: 200;
        body: {
            id: string;
            name: string;
            createdAt: Date;
            description: string | null;
        }[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getIntegrations: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            slack?: {
                nangoConnectionId: string;
                botUserId: string;
                teamId: string;
            } | null | undefined;
            email?: {
                connectionId: string;
                validateSPFandDKIM?: boolean | undefined;
            } | null | undefined;
            toolhouse?: {
                apiKey: string;
            } | null | undefined;
            langfuse?: {
                publicKey: string;
                secretKey: string;
                baseUrl: string;
                sendMessagePayloads: boolean;
            } | null | undefined;
            tavily?: {
                apiKey: string;
            } | null | undefined;
            valtown?: {
                endpoint: string;
                token: string;
            } | null | undefined;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly upsertIntegrations: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        body?: {
            slack?: {
                nangoConnectionId: string;
                botUserId: string;
                teamId: string;
            } | null | undefined;
            email?: {
                connectionId: string;
                validateSPFandDKIM?: boolean | undefined;
            } | null | undefined;
            toolhouse?: {
                apiKey: string;
            } | null | undefined;
            langfuse?: {
                publicKey: string;
                secretKey: string;
                baseUrl: string;
                sendMessagePayloads: boolean;
            } | null | undefined;
            tavily?: {
                apiKey: string;
            } | null | undefined;
            valtown?: {
                endpoint: string;
                token: string;
            } | null | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: undefined;
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 400;
        body: {
            message: string;
        };
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listEvents: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        query?: {
            type?: string | undefined;
            runId?: string | undefined;
            jobId?: string | undefined;
            machineId?: string | undefined;
            includeMeta?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            type: string;
            status: string | null;
            id: string;
            resultType: string | null;
            createdAt: Date;
            runId: string | null;
            jobId: string | null;
            targetFn: string | null;
            machineId: string | null;
            meta?: any;
        }[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 404;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getEventMeta: (args: {
        params: {
            clusterId: string;
            eventId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            type: string;
            status: string | null;
            id: string;
            resultType: string | null;
            createdAt: Date;
            jobId: string | null;
            targetFn: string | null;
            machineId: string | null;
            meta?: unknown;
        };
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 404;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listUsageActivity: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            modelUsage: {
                date: string;
                modelId: string | null;
                totalInputTokens: number;
                totalOutputTokens: number;
                totalModelInvocations: number;
            }[];
            runs: {
                date: string;
                totalRuns: number;
            }[];
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createRun: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
            "x-provider-key"?: undefined;
            "x-provider-model"?: undefined;
            "x-provider-url"?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            "x-provider-key"?: string | undefined;
            "x-provider-model"?: "claude-3-7-sonnet-20250219" | "claude-3-7-sonnet-latest" | "claude-3-5-sonnet-20241022" | "claude-3-5-sonnet-latest" | "claude-3-5-sonnet-20240620" | "claude-3-5-haiku-20241022" | "claude-3-5-haiku-latest" | undefined;
            "x-provider-url"?: "https://api.anthropic.com" | undefined;
            authorization?: string | undefined;
        } | undefined;
        body?: {
            id?: string | undefined;
            name?: string | undefined;
            input?: import("zod").objectInputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
            runId?: string | undefined;
            initialPrompt?: string | undefined;
            systemPrompt?: string | undefined;
            resultSchema?: import("zod").objectInputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
            tools?: string[] | undefined;
            attachedFunctions?: {
                function: string;
                service: string;
            }[] | undefined;
            onStatusChange?: unknown;
            tags?: Record<string, string> | undefined;
            context?: import("zod").objectInputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
            reasoningTraces?: boolean | undefined;
            interactive?: boolean | undefined;
            enableResultGrounding?: boolean | undefined;
        } | undefined;
    }) => Promise<{
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 400;
        body: {
            message: string;
        };
        headers: Headers;
    } | {
        status: 201;
        body: {
            status: "pending" | "running" | "paused" | "done" | "failed";
            id: string;
            result: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | null;
        };
        headers: Headers;
    } | {
        status: 200 | 204 | 410 | 404 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly deleteRun: (args: {
        params: {
            runId: string;
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listRuns: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        query?: {
            type?: "workflow" | "conversation" | "all" | undefined;
            userId?: string | undefined;
            tags?: string | undefined;
            limit?: number | undefined;
            test?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            type: "single-step" | "multi-step";
            status: "pending" | "running" | "paused" | "done" | "failed" | null;
            userId: string | null;
            id: string;
            name: string;
            createdAt: Date;
            test: boolean;
            feedbackScore: number | null;
            workflowExecutionId: string | null;
            workflowVersion: number | null;
            workflowName: string | null;
        }[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getRun: (args: {
        params: {
            clusterId: string;
            runId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            type: "single-step" | "multi-step" | null;
            status: "pending" | "running" | "paused" | "done" | "failed" | null;
            userId: string | null;
            id: string;
            result: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | null;
            tools: string[] | null;
            tags: Record<string, string> | null;
            test: boolean;
            feedbackScore: number | null;
            failureReason: string | null;
            feedbackComment: string | null;
            context?: any;
            authContext?: any;
        };
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createFeedback: (args: {
        params: {
            runId: string;
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            comment: string | null;
            score: number | null;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 404;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 410 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly oas: (args?: {
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: Record<string, string | undefined> | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
    } | undefined) => Promise<{
        status: 200;
        body: unknown;
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createMessage: (args: {
        params: {
            runId: string;
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            message: string;
            type?: "human" | "supervisor" | undefined;
            id?: string | undefined;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 201;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 204 | 410 | 404 | 400 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listMessages: (args: {
        params: {
            clusterId: string;
            runId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        query?: {
            waitTime?: number | undefined;
            limit?: number | undefined;
            after?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: ({
            type: "agent";
            id: string;
            data: {
                message?: string | undefined;
                done?: boolean | undefined;
                result?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
                learnings?: {
                    summary: string;
                    entities: {
                        type: "tool";
                        name: string;
                    }[];
                    relevance: {
                        temporality: "transient" | "persistent";
                    };
                }[] | undefined;
                issue?: string | undefined;
                invocations?: {
                    toolName: string;
                    input: {} & {
                        [k: string]: unknown;
                    };
                    id?: string | undefined;
                    reasoning?: string | undefined;
                }[] | undefined;
            };
            pending?: boolean | undefined;
            createdAt?: Date | undefined;
            metadata?: Record<string, unknown> | null | undefined;
        } | {
            type: "invocation-result";
            id: string;
            data: {
                id: string;
                toolName: string;
                resultType: "resolution" | "rejection";
                result: {} & {
                    [k: string]: unknown;
                };
            };
            pending?: boolean | undefined;
            createdAt?: Date | undefined;
            metadata?: Record<string, unknown> | null | undefined;
        } | {
            type: "human";
            id: string;
            data: {
                message: string;
                details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
            };
            pending?: boolean | undefined;
            createdAt?: Date | undefined;
            metadata?: Record<string, unknown> | null | undefined;
        } | {
            type: "template";
            id: string;
            data: {
                message: string;
                details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
            };
            pending?: boolean | undefined;
            createdAt?: Date | undefined;
            metadata?: Record<string, unknown> | null | undefined;
        } | {
            type: "supervisor";
            id: string;
            data: {
                message: string;
                details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
            };
            pending?: boolean | undefined;
            createdAt?: Date | undefined;
            metadata?: Record<string, unknown> | null | undefined;
        } | {
            type: "agent-invalid";
            id: string;
            data: {
                message: string;
                details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
            };
            pending?: boolean | undefined;
            createdAt?: Date | undefined;
            metadata?: Record<string, unknown> | null | undefined;
        })[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createApiKey: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            name: string;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            id: string;
            key: string;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listApiKeys: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            id: string;
            name: string;
            createdAt: Date;
            createdBy: string;
            revokedAt: Date | null;
        }[];
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly revokeApiKey: (args: {
        params: {
            clusterId: string;
            keyId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 204;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 401 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listMachines: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        query?: {
            limit?: number | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            id: string;
            lastPingAt: Date;
            ip: string;
        }[];
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getRunTimeline: (args: {
        params: {
            runId: string;
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        query?: {
            messagesAfter?: string | undefined;
            activityAfter?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            messages: ({
                type: "agent";
                id: string;
                data: {
                    message?: string | undefined;
                    done?: boolean | undefined;
                    result?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
                    learnings?: {
                        summary: string;
                        entities: {
                            type: "tool";
                            name: string;
                        }[];
                        relevance: {
                            temporality: "transient" | "persistent";
                        };
                    }[] | undefined;
                    issue?: string | undefined;
                    invocations?: {
                        toolName: string;
                        input: {} & {
                            [k: string]: unknown;
                        };
                        id?: string | undefined;
                        reasoning?: string | undefined;
                    }[] | undefined;
                };
                pending?: boolean | undefined;
                createdAt?: Date | undefined;
                metadata?: Record<string, unknown> | null | undefined;
            } | {
                type: "invocation-result";
                id: string;
                data: {
                    id: string;
                    toolName: string;
                    resultType: "resolution" | "rejection";
                    result: {} & {
                        [k: string]: unknown;
                    };
                };
                pending?: boolean | undefined;
                createdAt?: Date | undefined;
                metadata?: Record<string, unknown> | null | undefined;
            } | {
                type: "human";
                id: string;
                data: {
                    message: string;
                    details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
                };
                pending?: boolean | undefined;
                createdAt?: Date | undefined;
                metadata?: Record<string, unknown> | null | undefined;
            } | {
                type: "template";
                id: string;
                data: {
                    message: string;
                    details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
                };
                pending?: boolean | undefined;
                createdAt?: Date | undefined;
                metadata?: Record<string, unknown> | null | undefined;
            } | {
                type: "supervisor";
                id: string;
                data: {
                    message: string;
                    details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
                };
                pending?: boolean | undefined;
                createdAt?: Date | undefined;
                metadata?: Record<string, unknown> | null | undefined;
            } | {
                type: "agent-invalid";
                id: string;
                data: {
                    message: string;
                    details?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | undefined;
                };
                pending?: boolean | undefined;
                createdAt?: Date | undefined;
                metadata?: Record<string, unknown> | null | undefined;
            })[];
            activity: {
                type: string;
                id: string;
                createdAt: Date;
                jobId: string | null;
                targetFn: string | null;
                machineId: string | null;
            }[];
            jobs: {
                status: string;
                id: string;
                resultType: string | null;
                createdAt: Date;
                targetFn: string;
                approved: boolean | null;
                approvalRequested: boolean | null;
            }[];
            run: {
                status: "pending" | "running" | "paused" | "done" | "failed" | null;
                userId: string | null;
                id: string;
                name: string | null;
                systemPrompt: string | null;
                tools: string[] | null;
                interactive: boolean;
                test: boolean;
                feedbackScore: number | null;
                workflowExecutionId: string | null;
                workflowVersion: number | null;
                workflowName: string | null;
                failureReason: string | null;
                feedbackComment: string | null;
                result?: import("zod").objectOutputType<{}, import("zod").ZodTypeAny, "passthrough"> | null | undefined;
                tags?: Record<string, string> | null | undefined;
                context?: any;
                authContext?: any;
            };
        };
        headers: Headers;
    } | {
        status: 404;
        body: undefined;
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createNangoSession: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            integration: string;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            token: string;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createNangoEvent: (args: {
        cache?: RequestCache | undefined;
        headers: {
            "x-nango-signature": string;
        };
        body: import("zod").objectInputType<{}, import("zod").ZodTypeAny, "passthrough">;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            "x-nango-signature"?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
    }) => Promise<{
        status: 200;
        body: undefined;
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listWorkflows: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            version: number;
            name: string;
            description: string | null;
            schema: string | null;
        }[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createWorkflowExecution: (args: {
        params: {
            clusterId: string;
            workflowName: string;
        };
        cache?: RequestCache | undefined;
        body: import("zod").objectInputType<{
            executionId: import("zod").ZodString;
        }, import("zod").ZodTypeAny, "passthrough">;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 201;
        body: {
            jobId: string;
        };
        headers: Headers;
    } | {
        status: 200 | 401 | 204 | 410 | 404 | 400 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createWorkflowLogLegacy: (args: {
        params: {
            executionId: string;
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            status: "info" | "warn" | "error";
            data: {} & {
                [k: string]: unknown;
            };
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 201;
        body: {
            status: "info" | "warn" | "error";
            id: string;
            createdAt: Date;
            workflowExecutionId: string;
        };
        headers: Headers;
    } | {
        status: 200 | 401 | 204 | 410 | 404 | 400 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createWorkflowLog: (args: {
        params: {
            executionId: string;
            clusterId: string;
            workflowName: string;
        };
        cache?: RequestCache | undefined;
        body: {
            status: "info" | "warn" | "error";
            data: {} & {
                [k: string]: unknown;
            };
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 201;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 401 | 204 | 410 | 404 | 400 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly createWorkflowNotification: (args: {
        params: {
            workflowName: string;
            executionId: string;
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        body?: {
            message?: string | undefined;
            destination?: {
                type: "slack";
                channelId?: string | undefined;
                threadId?: string | undefined;
                userId?: string | undefined;
                email?: string | undefined;
            } | {
                type: "email";
                email: string;
            } | undefined;
        } | undefined;
    }) => Promise<{
        status: 201;
        body: undefined;
        headers: Headers;
    } | {
        status: 200 | 401 | 204 | 410 | 404 | 400 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listWorkflowExecutions: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
        query?: {
            limit?: number | undefined;
            workflowExecutionId?: string | undefined;
            workflowVersion?: string | undefined;
            workflowName?: string | undefined;
            workflowExecutionStatus?: "pending" | "running" | "success" | "failure" | "stalled" | "interrupted" | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            runs: {
                type: "single-step" | "multi-step" | null;
                status: "pending" | "running" | "paused" | "done" | "failed" | null;
                id: string | null;
                name: string | null;
                createdAt: Date | null;
                failureReason: string | null;
            }[];
            execution: {
                id: string;
                createdAt: Date;
                jobId: string;
                workflowVersion: number;
                workflowName: string;
                updatedAt: Date;
            };
            job: {
                status: "pending" | "running" | "success" | "failure" | "stalled" | "interrupted" | null;
                id: string | null;
                resultType: string | null;
                result: string | null;
                createdAt: Date;
                targetFn: string | null;
                targetArgs: string | null;
                executingMachineId?: string | null | undefined;
                approved?: boolean | null | undefined;
                approvalRequested?: boolean | null | undefined;
            };
        }[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getWorkflowExecutionTimeline: (args: {
        params: {
            executionId: string;
            clusterId: string;
            workflowName: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            runs: {
                type: "single-step" | "multi-step";
                status: "pending" | "running" | "paused" | "done" | "failed" | null;
                userId: string | null;
                id: string;
                name: string;
                createdAt: Date;
                failureReason: string | null;
            }[];
            execution: {
                id: string;
                createdAt: Date;
                workflowVersion: number;
                workflowName: string;
                job: {
                    status: string;
                    id: string;
                    resultType: string | null;
                    result: string | null;
                    createdAt: Date;
                    targetFn: string;
                    executingMachineId: string | null;
                    targetArgs: string;
                    approved: boolean | null;
                    approvalRequested: boolean | null;
                };
            };
            events: {
                type: string;
                status: string | null;
                id: string;
                resultType: string | null;
                createdAt: Date;
                runId: string | null;
                jobId: string | null;
                targetFn: string | null;
                machineId: string | null;
                meta?: any;
            }[];
            memos: {
                value: string;
                createdAt: Date;
                key: string;
            }[];
            structured: {
                value: string;
                createdAt: Date;
                key: string;
            }[];
        };
        headers: Headers;
    } | {
        status: 404;
        body: undefined;
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly setClusterKV: (args: {
        params: {
            clusterId: string;
            key: string;
        };
        cache?: RequestCache | undefined;
        body: {
            value: string;
            onConflict: "replace" | "doNothing";
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            value: string;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly getClusterKV: (args: {
        params: {
            clusterId: string;
            key: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            value: string;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly listTools: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            name: string;
            createdAt: Date;
            description: string | null;
            schema: string | null;
            config: {
                cache?: {
                    keyPath: string;
                    ttlSeconds: number;
                } | undefined;
                retryCountOnStall?: number | undefined;
                timeoutSeconds?: number | undefined;
                private?: boolean | undefined;
            } | null;
            lastPingAt: Date | null;
            shouldExpire: boolean;
        }[];
        headers: Headers;
    } | {
        status: 401;
        body: undefined;
        headers: Headers;
    } | {
        status: 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
    readonly l1mStructured: (args: {
        params: {
            clusterId: string;
        };
        cache?: RequestCache | undefined;
        body: {
            input: string;
            schema: Record<string, any>;
            instructions?: string | undefined;
        };
        fetchOptions?: import("@ts-rest/core").FetchOptions | undefined;
        extraHeaders?: ({
            authorization?: undefined;
            "x-provider-key"?: undefined;
            "x-provider-model"?: undefined;
            "x-provider-url"?: undefined;
            "x-max-attempts"?: undefined;
            "x-cache-ttl"?: undefined;
            "x-workflow-execution-id"?: undefined;
        } & Record<string, string | undefined>) | undefined;
        overrideClientOptions?: Partial<import("@ts-rest/core").OverrideableClientArgs> | undefined;
        headers?: {
            "x-provider-key"?: string | undefined;
            "x-provider-model"?: string | undefined;
            "x-provider-url"?: string | undefined;
            "x-max-attempts"?: string | undefined;
            "x-cache-ttl"?: string | undefined;
            "x-workflow-execution-id"?: string | undefined;
            authorization?: string | undefined;
        } | undefined;
    }) => Promise<{
        status: 200;
        body: {
            data: Record<string, any>;
        };
        headers: Headers;
    } | {
        status: 401 | 204 | 410 | 404 | 400 | 201 | 100 | 101 | 102 | 202 | 203 | 205 | 206 | 207 | 300 | 301 | 302 | 303 | 304 | 305 | 307 | 308 | 402 | 403 | 405 | 406 | 407 | 408 | 409 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 428 | 429 | 431 | 451 | 500 | 501 | 502 | 503 | 504 | 505 | 507 | 511;
        body: unknown;
        headers: Headers;
    }>;
};
