"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleCustomAuthInput = exports.onStatusChangeInput = void 0;
const zod_1 = require("zod");
/**
 * Schema for onStatusChange functions
 *
 * @see {@link https://docs.inferable.ai/pages/runs#onstatuschange}
 * @example
 * ```ts
 * inferable.default.register({
 *   name: "onStatusChangeFn",
 *   schema: {
 *    input: onStatusChangeInput
 *   },
 *   func: (_input) => {},
 * });
 * ```
 */
exports.onStatusChangeInput = zod_1.z.object({
    runId: zod_1.z.string(),
    status: zod_1.z.enum(["pending", "running", "paused", "done", "failed"]),
    result: zod_1.z.object({}).passthrough().nullable().optional(),
    summary: zod_1.z.string().nullable().optional(),
    tags: zod_1.z.record(zod_1.z.string()).nullable().optional(),
});
/**
 * Schema for handleCustomAuth functions
 *
 * @see {@link https://docs.inferable.ai/pages/custom-auth}
 * @example
 * ```ts
 * inferable.default.register({
 *   name: "handleCustomAuth",
 *   schema: {
 *    input: handleCustomAuthInput
 *   },
 *   func: (_input) => {},
 * });
 * ```
 */
exports.handleCustomAuthInput = zod_1.z.object({
    token: zod_1.z.string(),
});
//# sourceMappingURL=types.js.map